export interface User {
  id: number
  username: string
  role: 'admin' | 'user'
  created_at: string
}

export interface AuthUser extends User {
  token?: string
}

export interface LoginCredentials {
  username: string
  password: string
}

export interface Certificate {
  id: number
  name: string
  type: 'root' | 'intermediate' | 'simple'
  functional_perimeter_id?: number
  perimeter_name?: string
  expiration_date: string
  is_revoked: boolean
  revoked_at?: string
  created_at: string
}

export interface CreateCertificateData {
  subdomain_name: string
  functional_perimeter_id: number
}

export interface FunctionalPerimeter {
  id: number
  name: string
  intermediate_cert_name: string
  created_at: string
}

export interface CreatePerimeterData {
  name: string
  intermediate_passphrase?: string
}

export interface CreateUserData {
  username: string
  password: string
  role: 'admin' | 'user'
}

export interface UpdatePasswordData {
  user_id: number
  new_password: string
  confirm_password: string
}

export interface DashboardStats {
  total_certificates: number
  active_certificates: number
  revoked_certificates: number
  total_perimeters: number
  total_users: number
  expiring_soon: Certificate[]
}

export interface ApiResponse<T = unknown> {
  success: boolean
  data?: T
  message?: string
  errors?: Record<string, string[]>
}

export interface PaginatedResponse<T> {
  data: T[]
  current_page: number
  per_page: number
  total: number
  last_page: number
}

export type Theme = 'light' | 'dark'

export type Language = 'en' | 'fr' | 'de' | 'es' | 'it' | 'pt' | 'ja' | 'ru' | 'ar' | 'hi' | 'zh'

export interface DownloadCertificateParams {
  type: 'root' | 'intermediate' | 'simple'
  file: string
  perimeter?: string
}